=====================================
Faker Addon for Gas & Power Utilities
=====================================

|PyPI Package| |PyPI Python Versions| |Last Commit|

Basic Usage
-----------

Install with pip:

.. code:: bash

    pip install faker_utilities

    Use ``faker.Faker()`` to create and initialize a faker generator, 
    which can generate data by accessing properties named after the type of data you want.
    
  
   
.. |Last Commit| image:: https://img.shields.io/github/last-commit/xantygc/faker_utilities
   :target: https://pypi.org/project/faker-wifi-essid/
   :alt: PyPI Package Python Versions
   
.. |PyPI Python Versions| image:: https://img.shields.io/pypi/pyversions/faker-utilities.svg?logo=python&style=flat
   :target: https://pypi.org/project/faker-wifi-essid/
   :alt: PyPI Package Python Versions

.. |PyPI Package| image:: https://img.shields.io/pypi/v/faker-utilities.svg?style=flat
   :target: https://pypi.org/project/faker-utilities/
   :alt: PyPI Package Latest Release
